==> spark_ai_python-0.1.6-py3-none-any.whl: sparkai/api_resources/__init__.py <==
#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: __init__.py
@time: 2023/07/23
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
import os

# Path of a file with an API key, whose contents can change. Supercedes
# `api_key` if set.  The main use case is volume-mounted Kubernetes secrets,
# which are updated automatically.

print("getting config from env: SPARK_API_BASE,SPARK_APP_ID,SPARK_API_KEY,SPARK_API_SECRET")
api_base = os.environ.get("SPARK_API_BASE", "wss://aichat.xf-yun.com/v1/chat")
api_type = os.environ.get("SPARK_API_TYPE", "spark")
api_domain = os.environ.get("SPARK_DOMAIN", "general")

app_id = os.environ.get("SPARK_APP_ID")
api_key = os.environ.get("SPARK_API_KEY")
api_secret = os.environ.get("SPARK_API_SECRET")

==> spark_ai_python-0.3.7-py3-none-any.whl: sparkai/api_resources/__init__.py <==
#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: __init__.py
@time: 2023/07/23
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
import os

# Path of a file with an API key, whose contents can change. Supercedes
# `api_key` if set.  The main use case is volume-mounted Kubernetes secrets,
# which are updated automatically.

print("getting config from env: SPARK_API_BASE,SPARK_APP_ID,SPARK_API_KEY,SPARK_API_SECRET")
api_base = os.environ.get("SPARK_API_BASE", "wss://spark-api.xf-yun.com/v2.1/chat")
api_type = os.environ.get("SPARK_API_TYPE", "spark")
api_domain = os.environ.get("SPARK_DOMAIN", "plugin")

app_id = os.environ.get("SPARK_APP_ID")
api_key = os.environ.get("SPARK_API_KEY")
api_secret = os.environ.get("SPARK_API_SECRET")
